Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorKarsten Thoms2018-02-01 08:50:52 +0000
committerAlexander Kurtakov2018-02-15 13:12:50 +0000
commitec65bd6a75cfaab71bee21b1f1a96c95dbe51539 (patch)
treee65271f2e77f28a704ca67da6a694732a8a7c142
parent9f83fe1e8ff87ddf3a7c4782f42a843fb5ba0e64 (diff)
downloadrt.equinox.p2-ec65bd6a75cfaab71bee21b1f1a96c95dbe51539.tar.gz
rt.equinox.p2-ec65bd6a75cfaab71bee21b1f1a96c95dbe51539.tar.xz
rt.equinox.p2-ec65bd6a75cfaab71bee21b1f1a96c95dbe51539.zip
Bug 530592 - Fixed typo in temp file name
Change-Id: I86648442f44dfbc1abf1293a7c9dd895cf46c98f Signed-off-by: Karsten Thoms <karsten.thoms@itemis.de>
-rw-r--r--bundles/org.eclipse.equinox.p2.director.app/src/org/eclipse/equinox/internal/p2/director/app/DirectorApplication.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/bundles/org.eclipse.equinox.p2.director.app/src/org/eclipse/equinox/internal/p2/director/app/DirectorApplication.java b/bundles/org.eclipse.equinox.p2.director.app/src/org/eclipse/equinox/internal/p2/director/app/DirectorApplication.java
index 4409ba564..9ca6c51a7 100644
--- a/bundles/org.eclipse.equinox.p2.director.app/src/org/eclipse/equinox/internal/p2/director/app/DirectorApplication.java
+++ b/bundles/org.eclipse.equinox.p2.director.app/src/org/eclipse/equinox/internal/p2/director/app/DirectorApplication.java
@@ -1399,9 +1399,9 @@ public class DirectorApplication implements IApplication, ProvisioningListener {
try {
// we use the .dll suffix to properly test on Vista virtual directories
// on Vista you are not allowed to write executable files on virtual directories like "Program Files"
- fileTest = File.createTempFile("writtableArea", ".dll", installDir); //$NON-NLS-1$ //$NON-NLS-2$
+ fileTest = File.createTempFile("writableArea", ".dll", installDir); //$NON-NLS-1$ //$NON-NLS-2$
} catch (IOException e) {
//If an exception occured while trying to create the file, it means that it is not writtable
return false;
} finally {
if (fileTest != null)
@@ -1399,9 +1399,9 @@ public class DirectorApplication implements IApplication, ProvisioningListener {
} catch (IOException e) {
- //If an exception occured while trying to create the file, it means that it is not writtable
+ //If an exception occured while trying to create the file, it means that it is not writable
return false;
} finally {

Back to the top